from AioPTTCrawler import AioPTTCrawler

def main():
    ptt_crawler = AioPTTCrawler()


if __name__ == "__main__":
    main()
